@@ -326,7 +326,7 @@ sub retag{
 
 	#clean up the new line
 	my $new_line = join " ", @newSet;
-	$new_line =~s/\b$entId\b//g;
+	$new_line =~s/\b$entId\b//og;
 	$new_line = $uniSub->cleanWords($new_line);
 	return $new_line;
 }
@@ -362,8 +362,8 @@ sub untag{
 
 	my $input = lc($line);
 	$id = lc($id);
-	$input =~ s/ <start:$id>//g;
-	$input =~ s/ <end>//g;
+	$input =~ s/ <start:$id>//og;
+	$input =~ s/ <end>//og;
 	$input = $uniSub->cleanWords($input);
 	return $input;
 }
@@ -490,16 +490,16 @@ sub cleanToken{
 	my $tokenText = $text;
 
 	#fix "# . #" tokens
-	if($tokenText =~ /\d+\s\.\s\d+/){
-		$tokenText =~s/\s\.\s/\./g;
+	if($tokenText =~ /\d+\s\.\s\d+/o){
+		$tokenText =~s/\s\.\s/\./og;
 	}
 
 	#fix "__ \' __" tokens
-	if($tokenText =~ /\w+\s\\\'\s\w+/){
-		$tokenText =~s/\s\\\'\s//g;
+	if($tokenText =~ /\w+\s\\\'\s\w+/o){
+		$tokenText =~s/\s\\\'\s//og;
 	}
 
-	if($tokenText =~ /[^a-zA-Z0-9]/){
+	if($tokenText =~ /[^a-zA-Z0-9]/o){
 		$tokenText = "";
 	}
 
@@ -632,8 +632,7 @@ sub getFeature{
 	if($type eq "pos"){
 		#get the token and it's pos tag
 		foreach my $key (sort keys %tokenHash){
-			my @tokens = @{$tokenHash{$key}};
-			foreach my $token(@tokens){
+			foreach my $token(@{$tokenHash{$key}}){
 				my $tokenTxt = $token->{text};
 				if($tokenTxt eq $word){
 					return $token->{posTag};
@@ -644,8 +643,7 @@ sub getFeature{
 	}elsif($type eq "sem" or $type eq "cui"){
 		#get the concept and it's cui or sem tag
 		foreach my $key (sort keys %conceptHash){
-			my @concepts = @{$conceptHash{$key}};
-			foreach my $concept (@concepts){
+			foreach my $concept (@{$conceptHash{$key}}){
 				my $ohboi = @$concept[0];
 				my $name = lc($ohboi->{text});
 				if($name eq $word){
@@ -936,6 +934,7 @@ sub vectorMaker{
 
 			$| = 1;
 
+			my $wordOrig = $words[$a];	
 			#make the words for comparison
 			my $word = $words[$a];
 			my $prevWord = "";
@@ -951,7 +950,7 @@ sub vectorMaker{
 				$smlword .= "...";
 			}
 			
-			if($word =~/$entId/){
+			if($word =~/$entId/o){
 				$uniSub->printColorDebug("red", "$smlword!                ");
 			}else{
 				$uniSub->printDebug("$smlword!                    ")
@@ -973,9 +972,9 @@ sub vectorMaker{
 			
 
 			#get rid of tag if necessary
-			$prevWord =~s/$entId//g;
-			$nextWord =~s/$entId//g;
-			$word =~s/$entId//g;
+			$prevWord =~s/$entId//og;
+			$nextWord =~s/$entId//og;
+			$word =~s/$entId//og;
 
 			my $vec = "";
 			#use each set of attributes
@@ -996,11 +995,12 @@ sub vectorMaker{
 			#convert binary to sparse if specified
 			if($sparse_matrix){
 				$vec = convert2Sparse($vec);
+				#$uniSub->printColorDebug("red", "$vec\n");
 			}
 
 			#check if the word is an entity or not
-			my $wordOrig = $words[$a];	
-			$vec .= (($wordOrig =~/([\s\S]*($entId)$)/) ? "Yes " : "No ");
+			#$uniSub->printColorDebug("red", "\n$wordOrig\n");
+			$vec .= (($wordOrig =~/\b[\S]+(_e)\b/) ? "Yes " : "No ");
 
 			#close it if using sparse matrix
 			if($sparse_matrix){
@@ -1030,7 +1030,7 @@ sub orthoVec{
 	my $addon = "";
 
 	#check if first letter capital
-	$addon = ($word =~ /\b([A-Z])\w+\b/g ? 1 : 0);
+	$addon = ($word =~ /\b([A-Z])\w+\b/og ? 1 : 0);
 	$strVec .= "$addon, ";
 
 	#check if a single letter word
@@ -1038,23 +1038,23 @@ sub orthoVec{
 	$strVec .= "$addon, ";
 
 	#check if all capital letters
-	$addon = ($word =~ /\b[A-Z]+\b/g ? 1 : 0);
+	$addon = ($word =~ /\b[A-Z]+\b/og ? 1 : 0);
 	$strVec .= "$addon, ";
 
 	#check if contains a digit
-	$addon = ($word =~ /[0-9]+/g ? 1 : 0);
+	$addon = ($word =~ /[0-9]+/og ? 1 : 0);
 	$strVec .= "$addon, ";
 
 	#check if all digits
-	$addon = ($word =~ /\b[0-9]+\b/g ? 1 : 0);
+	$addon = ($word =~ /\b[0-9]+\b/og ? 1 : 0);
 	$strVec .= "$addon, ";
 
 	#check if contains a hyphen
-	$addon = ($word =~ /-/g ? 1 : 0);
+	$addon = ($word =~ /-/og ? 1 : 0);
 	$strVec .= "$addon, ";
 
 	#check if contains punctuation
-	$addon = ($word =~ /[^a-zA-Z0-9\s]/g ? 1 : 0);
+	$addon = ($word =~ /[^a-zA-Z0-9\s]/og ? 1 : 0);
 	$strVec .= "$addon, ";
 
 	return $strVec;
@@ -1232,14 +1232,16 @@ sub semVec{
 #converts a binary vector to a sparse vector
 sub convert2Sparse{
 	my $bin_vec = shift;
-	my @vals = split(",", $bin_vec);
+	my @vals = split(", ", $bin_vec);
 	my $numVals = @vals;
 
 	my $sparse_vec = "{";
 	for(my $c=0;$c<$numVals;$c++){
 		my $curVal = $vals[$c];
-		if($curVal eq "1"){
-			$sparse_vec .= "$c" . "$curVal, ";
+
+		if(($curVal eq "1")){
+			$sparse_vec .= "$c $curVal, ";
+			#$uniSub->printColorDebug("red", "$c $curVal, ");
 		}
 	}
 	$sparse_vec .= "$numVals, ";
@@ -1334,7 +1336,7 @@ sub makeUniq{
 
 	my @new_arr = ();
 	foreach my $t (@orig_arr){
-		unless($uniSub->inArr($t, \@new_arr) or $t =~/\s+/ or $t =~/\b$entId\b/ or length($t) == 0){
+		unless($uniSub->inArr($t, \@new_arr) or $t =~/\s+/o or $t =~/\b$entId\b/o or length($t) == 0){
 			push @new_arr, $t;
 		}
 	}
@@ -1391,7 +1393,7 @@ sub getRangeAttributes{
 			my $tokenText = $token->{text};
 
 			#add to the tokens
-			if($tokenText =~ /\w+\s\w+/){
+			if($tokenText =~ /\w+\s\w+/o){
 				my @tokenText2 = split(" ", $tokenText);
 				push @tokenWords, @tokenText2;
 			}elsif($tokenText ne "." and $tokenText ne "-" and !($tokenText =~ /[^a-zA-Z0-9]/)){
